###########
Citing GWpy
###########

If you have used GWpy as part of a project that leads to a scientific
publication, please acknowledge this by citing the
:doi:`GWpy paper <10.1016/j.softx.2021.100657>`.

----

.. tab-set::

    .. tab-item:: BibTeX
        :name: gwpy-citation-bibtex

        .. code-block:: bibtex

            @article{gwpy,
                title = "{GWpy: A Python package for gravitational-wave astrophysics}",
               author = {{Macleod}, D.~M. and {Areeda}, J.~S. and {Coughlin}, S.~B. and {Massinger}, T.~J. and {Urban}, A.~L.},
              journal = {SoftwareX},
               volume = 13,
                pages = 100657,
                 year = 2021,
                 issn = {2352-7110},
                  doi = {10.1016/j.softx.2021.100657},
                  url = {https://www.sciencedirect.com/science/article/pii/S2352711021000029},
            }

    .. tab-item:: RIS
        :name: gwpy-citation-ris

        .. code-block::

            TY  - JOUR
            T1  - GWpy: A Python package for gravitational-wave astrophysics
            AU  - Macleod, Duncan M.
            AU  - Areeda, Joseph S.
            AU  - Coughlin, Scott B.
            AU  - Massinger, Thomas J.
            AU  - Urban, Alexander L.
            JO  - SoftwareX
            VL  - 13
            SP  - 100657
            PY  - 2021
            DA  - 2021/01/01/
            SN  - 2352-7110
            DO  - 10.1016/j.softx.2021.100657
            UR  - https://www.sciencedirect.com/science/article/pii/S2352711021000029
            ER  - 

    .. tab-item:: EndNote
        :name: gwpy-citation-endnote

         .. code-block::

            %0 Journal Article
            %T GWpy: A Python package for gravitational-wave astrophysics
            %A Macleod, Duncan M.
            %A Areeda, Joseph S.
            %A Coughlin, Scott B.
            %A Massinger, Thomas J.
            %A Urban, Alexander L.
            %J SoftwareX
            %V 13
            %P 100657
            %D 2021
            %R 10.1016/j.softx.2021.100657
            %@ 2352-7110

    .. tab-item:: RefWorks
        :name: gwpy-citation-refworks

        .. code-block::

            RT Journal
            T1 GWpy: A Python package for gravitational-wave astrophysics
            A1 Macleod, Duncan M.
            A1 Areeda, Joseph S.
            A1 Coughlin, Scott B.
            A1 Massinger, Thomas J.
            A1 Urban, Alexander L.
            JF SoftwareX
            VO 13
            SP 100657
            YR 2021
            DO DOI: 10.1016/j.softx.2021.100657
            SN 2352-7110
